package
Version:
v0.13.0
Opens a new window with list of versions in this module.
Published: May 9, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
DefaultTimeout = 120 * time.Second
DefaultMaxOutputChars = 50000
DefaultTruncationSuffix = "\n\n[truncated]"
)
func MaxOutputChars(value int) int
Source Files
¶
Click to show internal directories.
Click to hide internal directories.